@@ -146,7 +146,7 @@ test_gupnp_context_http_ranged_requests (void)
                                  DATA_PATH "/random4k.bin",
                                  "/random4k.bin");
 
-        uri = g_strdup_printf ("http://localhost:%u/random4k.bin", port);
+        uri = g_strdup_printf ("http://127.0.0.1:%u/random4k.bin", port);
         g_assert (uri != NULL);
 
         session = soup_session_async_new ();
@@ -222,7 +222,9 @@ test_gupnp_context_http_ranged_requests (void)
 }
 
 int main (int argc, char *argv[]) {
+#if !GLIB_CHECK_VERSION(2,35,0)
         g_type_init ();
+#endif
         g_test_init (&argc, &argv, NULL);
         g_test_add_func ("/context/http/ranged-requests",
                          test_gupnp_context_http_ranged_requests);
